// flyby.pov
//
// (C) 2012 Sander de Jong
//
// render: 
//   povray +Iflyby.pov +W640 +H480 +A +KC +KFF240
// convert to mp4: 
//   ffmpeg -f image2 -i flyby%03d.png -vcodec libx264 -vpre slow -vpre baseline -b 1500k flyby.mp4
// convert to webm:
//   ffmpeg -f image2 -i flyby%03d.png -vcodec libvpx -f webm -b 1500k flyby.webm
// play:
//   mplayer flyby.mp4 -loop 0

#include "colors.inc"
#include "textures.inc"

//
// Animation
//

#declare numsections = 4;
#declare section = floor( clock * numsections );

#declare ct_l  = clock * numsections - section;
#declare ct_lr = 1.0 - ct_l;
#declare ct_s  = sin(ct_l * 0.5 * pi);
#declare ct_sr = 1.0 - sin(ct_l * 0.5 * pi + 0.5 * pi);
#declare ct_q  = ct_l * ct_l;
#declare ct_qr = 1.0 - ct_l * ct_l; 


//
// Camera and lightsources
//

camera 
{
	look_at <0, 3.5, 0>

	#local cur_t = section/numsections + ct_l/numsections;
	#local cur_y = 2 + 1.5*(1-cos(2*pi*cur_t));
	#local cur_r = 0.5 + cos(2*pi*cur_t);
	#local cur_z = cur_r * cos(2*pi*cur_t);
	#local cur_x = cur_r * sin(2*pi*cur_t);
	 
	location <10*cur_x, cur_y, 12*cur_z -2>
}

light_source
{
	<2, 15, -4>
	color White
}

light_source
{
	<-4, 9, 8>
	color rgb <0.4, 0.4, 0.4>
}


//
// Background color and fog
//

background 
{
	color White
}

fog 
{
	distance 30
	color rgb <0.7, 0.7, 0.7>
}


//
// The scene
//

plane 
{
    y, 0
    pigment {checker Green, White}
}

sphere
{
	<0, 0, 0>, 0.5
	pigment { color Red }
    finish 
    {
    	ambient .1
		diffuse .6
		specular .75
		roughness .001
        reflection { .3 }
	}
	translate <-1, 3.5, 0>
}

sphere
{
	<0, 0, 0>, 0.5
	pigment { color Yellow }
    finish 
    {
    	ambient .1
		diffuse .6
		specular .75
		roughness .001
        reflection { .3 }
	}
	translate <0, 3.5, 0>
}

sphere
{
	<0, 0, 0>, 0.5
	pigment { color Blue }
    finish 
    {
    	ambient .1
		diffuse .6
		specular .75
		roughness .001
        reflection { .3 }
	}
	translate <1, 3.5, 0>
}

merge
{
	torus
	{
		2, 0.025
	}

	difference
	{
		sphere
		{
			<0, 0, 0>, 2.025
		}
		sphere
		{
			<0, 0, 0>, 1.975
		}
		box
		{
			<-3, -3, -3>, <3, 0, 3>
		}
	}
	pigment { color rgb <0.75, 1.0, 0.75> filter 0.90 }
	interior { ior 1.5 }
	finish { ambient 0 diffuse 0.1}
#if (section = 0)
	rotate <80*ct_sr,0,0>
#end	
#if (section = 1)
	rotate <80+80*ct_s,0,0>
#end
#if (section = 2)
	rotate <160-80*ct_sr,0,0>
#end
#if (section = 3)
	rotate <80-80*ct_s, 0, 0>
#end
	translate <0, 3, 0>
}

union
{
	difference
	{
		sphere
		{
			<0, 3, 0>, 2.1
		}
		box
		{
			<-3, 3, -3>, <3, 6, 3>
		}
		pigment { color White }
		finish { Metal }
	}
	union
	{	
		cylinder 
		{
	   	  	<-1.2, 0, -1.2>, <-1.2, 2.9, -1.2>, 0.125
		}
		cylinder 
		{
	     	<1.2, 0, -1.2>, <1.2, 2.9, -1.2>, 0.125
		}
		cylinder 
		{
     		<1.2, 0, 1.2>, <1.2, 2.9, 1.2>, 0.125
		}
		cylinder 
		{
	     	<-1.2, 0, 1.2>, <-1.2, 2.9, 1.2>, 0.125
		}
		pigment { color Pink }
		finish { Metal }
	}
}
	


#declare WalkingBox = box
{
	<-1, 0, -0.05>, <0, 1, 0.05>
	rotate <0, 0, -90*ct_sr>
	translate <section, 0, 0>
}
	
#declare idx = 0;
#while (idx < 20)

	object
	{
		WalkingBox
		pigment { color Red }
		finish { Metal }		
		translate <-10*4+4*idx, 0, 3>
	}
  
  	#declare idx = idx + 1;
#end

